@@ -9,6 +9,7 @@ use v5.14;
 
 # Module implementation here
 our %github;
+our $EXIT_CODE = 0;
 
 our @EXPORT = qw( %github set_output set_env debug error warning set_failed command_on_file error_on_file warning_on_file start_group end_group);
 
@@ -21,7 +22,7 @@ BEGIN {
   }
 }
 
-use version; our $VERSION = qv('0.1.0');
+use version; our $VERSION = qv('0.1.1');
 
 sub set_output {
   carp "Need name and value" unless @_;
@@ -44,6 +45,7 @@ sub debug {
 
 sub error {
   my $error_message = shift;
+  $EXIT_CODE = 1;
   say "::error::$error_message"
 }
 
@@ -87,6 +89,10 @@ sub set_failed {
   exit( 1);
 }
 
+sub exit_action {
+  exit( $EXIT_CODE );
+}
+
 "Action!"; # Magic true value required at end of module
 __END__
 
@@ -116,6 +122,12 @@ This document describes GitHub::Actions version 0.0.3
     # Set environment variable value
     set_env("FOO", "BAR");
 
+    # Produces an error and sets exit code to 1
+    error( "FOO has happened" )
+
+    # Exits with error if that's the case
+    exit_action();
+
 Install this module within a GitHub action
 
       . name: "Install GitHub::Actions"
@@ -185,12 +197,17 @@ Exits with an error status of 1 after setting the error message.
 
 =head2 start_group( $group_name )
 
-Starts a group in the logs, grouping the following messages. Corresponds to L<C<group>|https://docs.github.com/en/actions/reference/workflow-commands-for-github-actions#grouping-log-lines>.
+Starts a group in the logs, grouping the following messages. Corresponds to
+L<C<group>|https://docs.github.com/en/actions/reference/workflow-commands-for-github-actions#grouping-log-lines>.
 
 =head2 end_group
 
 Ends current log grouping.
 
+=head2 exit_action
+
+Exits with the exit code generated during run
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 GitHub::Actions requires no configuration files or environment
